@@ -25,9 +25,15 @@ import pywebsite.sqlitepickle
 
 
 import sys
+_import_again = False
 try:
     from .base import NewsletterSend, Newsletter
 except ImportError:
+    _import_again = True
+except ValueError:
+    _import_again = True
+
+if _import_again:
     # a hack to put the newsletter package in the path.
     sys.path.append(os.path.join("..", ".."))
     from newsletter.base import NewsletterSend, Newsletter
@@ -304,9 +310,15 @@ class MyNewsletter(Newsletter):
         self.config = config
         self.static_dir = config.get("static_dir")
         self.db_dir = config.get("db_dir")
-        self.fromaddr = config.get("from_addr")
+
+        if not os.path.exists(self.db_dir):
+            raise ValueError("Database dir for '%s' config item :db_dir: does not exist. Check the path, or consider making the directory." % self.db_dir)
+
         self.subscribers_db_path = os.path.join(self.db_dir, 
                                                 "subscribers.sqlitepickle")
+
+        self.fromaddr = config.get("from_addr")
+             
         Newsletter.__init__(self)
 
     def email_template(self, template_name):
@@ -822,17 +834,26 @@ def make_new_install(dst_directory):
     sys.path.append(os.path.join("..", ".."))
     import newsletter.newsletterapp
     
+    # do not copy in .py files.
+    def ignorepy(src, names):
+        return [n for n in names if (n.endswith("py") or n.endswith("pyc"))]
+
     src_dir =  os.path.split(os.path.abspath(newsletter.newsletterapp.__file__))[0]
     
     
     #print (src_dir, dst_directory)
-    shutil.copytree(src_dir, dst_directory)
+    shutil.copytree(src_dir, dst_directory, ignore=ignorepy)
 
     # create the log directory if it doesn't exist.
     log_dir = os.path.join(dst_directory, "log")
     if not os.path.exists(log_dir):
         os.mkdir(log_dir)
     
+    db_dir = os.path.join(dst_directory, "db")
+    if not os.path.exists(db_dir):
+        os.mkdir(db_dir)
+
+
     # update the config file to show the dst directory.
     
 
